@@ -1,19 +1,21 @@
 # Perl Routines to Manipulate CGI input
-# cgi-lib@pobox.com
-# $Id: cgi-lib.pl,v 2.15 1997/11/18 06:48:25 brenner Exp $
+# S.E.Brenner@bioc.cam.ac.uk
+# $Id: cgi-lib.pl,v 2.14 1996/10/20 12:41:02 brenner Exp $
 #
-# Copyright (c) 1997 Steven E. Brenner  
+# Copyright (c) 1996 Steven E. Brenner  
 # Unpublished work.
 # Permission granted to use and modify this library so long as the
 # copyright above is maintained, modifications are documented, and
 # credit is given for any use of the library.
 #
 # Thanks are due to many people for reporting bugs and suggestions
+# especially Meng Weng Wong, Maki Watanabe, Bo Frese Rasmussen,
+# Andrew Dalke, Mark-Jason Dominus, Dave Dittrich, Jason Mathews
 
 # For more information, see:
-#     http://cgi-lib.stanford.edu/cgi-lib/
+#     http://www.bio.cam.ac.uk/cgi-lib/
 
-$cgi_lib'version = sprintf("%d.%02d", q$Revision: 2.15 $ =~ /(\d+)\.(\d+)/);
+$cgi_lib'version = sprintf("%d.%02d", q$Revision: 2.14 $ =~ /(\d+)\.(\d+)/);
 
 
 # Parameters affecting cgi-lib behavior
@@ -139,7 +141,7 @@ $errflag = !(eval <<'END_MULTIPART');
     if ($writefiles) {
       local($me);
       stat ($writefiles);
-      $writefiles = "/tmp" unless  -d _ && -w _;
+      $writefiles = "/tmp" unless  -d _ && -r _ && -w _;
       # ($me) = $0 =~ m#([^/]*)$#;
       $writefiles .= "/$cgi_lib'filepre"; 
     }
@@ -183,13 +185,6 @@ $errflag = !(eval <<'END_MULTIPART');
  
      BODY: 
       while (($bpos = index($buf, $boundary)) == -1) {
-        if ($left == 0 && $buf eq '') {
-	  foreach $value (values %insfn) {
-            unlink(split("\0",$value));
-	  }
-	  &CgiDie("cgi-lib.pl: reached end of input while seeking boundary " .
-		  "of multipart. Format of CGI input is wrong.\n");
-        }
         die $@ if $errflag;
         if ($name) {  # if no $name, then it's the prologue -- discard
           if ($fn) { print FILE substr($buf, 0, $bufsize); }
@@ -197,7 +192,7 @@ $errflag = !(eval <<'END_MULTIPART');
         }
         $buf = substr($buf, $bufsize);
         $amt = ($left > $bufsize ? $bufsize : $left); #$maxbound==length($buf);
-        $errflag = (($got = read(STDIN, $buf, $amt, length($buf))) != $amt);
+        $errflag = (($got = read(STDIN, $buf, $amt, $maxbound)) != $amt);  
 	die "Short Read: wanted $amt, got $got\n" if $errflag;
         $left -= $amt;
       }
@@ -206,7 +201,7 @@ $errflag = !(eval <<'END_MULTIPART');
         else     { $in {$name} .= substr($buf, 0, $bpos-2); } # kill last \r\n
       }
       close (FILE);
-      last PART if substr($buf, $bpos + $blen, 2) eq "--";
+      last PART if substr($buf, $bpos + $blen, 4) eq "--\r\n";
       substr($buf, 0, $bpos+$blen+2) = '';
       $amt = ($left > $bufsize+$maxbound-length($buf) 
 	      ? $bufsize+$maxbound-length($buf) : $left);
@@ -218,18 +213,11 @@ $errflag = !(eval <<'END_MULTIPART');
       undef $head;  undef $fn;
      HEAD:
       while (($lpos = index($buf, "\r\n\r\n")) == -1) { 
-        if ($left == 0  && $buf eq '') {
-	  foreach $value (values %insfn) {
-            unlink(split("\0",$value));
-	  }
-	  &CgiDie("cgi-lib: reached end of input while seeking end of " .
-		  "headers. Format of CGI input is wrong.\n$buf");
-        }
         die $@ if $errflag;
         $head .= substr($buf, 0, $bufsize);
         $buf = substr($buf, $bufsize);
         $amt = ($left > $bufsize ? $bufsize : $left); #$maxbound==length($buf);
-        $errflag = (($got = read(STDIN, $buf, $amt, length($buf))) != $amt);
+        $errflag = (($got = read(STDIN, $buf, $amt, $maxbound)) != $amt);  
         die "Short Read: wanted $amt, got $got\n" if $errflag;
         $left -= $amt;
       }
@@ -310,7 +298,7 @@ sub HtmlTop
 <head>
 <title>$title</title>
 </head>
-<body bgcolor="white">
+<body BGCOLOR=#FFFFFF>
 END_OF_TEXT
 # <h1>$title</h1>
 }
@@ -405,7 +393,7 @@ sub CgiError {
   };
 
   if (!$cgi_lib'headerout) { #')
-    print &PrintHeader;	
+#   print &PrintHeader;	
     print "<html>\n<head>\n<title>$msg[0]</title>\n</head>\n<body>\n";
   }
   print "<h1>$msg[0]</h1>\n";
@@ -423,8 +411,8 @@ sub CgiError {
 sub CgiDie {
   local (@msg) = @_;
   &CgiError (@msg);
-  # die @msg;
   exit (0);
+  # die @msg;
 }
 
 
